==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebChipDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { WebChipDescription } from "./WebChipDescription";
/**
 * @hidden
 */
export let WebChipDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebChipDescriptionMetadata extends Base {
        static b(a) {
            if (WebChipDescriptionMetadata.a == null) {
                WebChipDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebChipDescriptionMetadata.c(WebChipDescriptionMetadata.a);
            }
            if (a.k(WebChipDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebChipDescriptionMetadata.a);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Chip");
            a.item("__tagNameWC", "String:igc-chip");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Disabled", "Boolean");
            a.item("Removable", "Boolean");
            a.item("Selectable", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Variant", "ExportedType:string:ChipVariant");
            a.item("Variant@stringUnion", "WebComponents;React");
            a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
            a.item("RemoveRef", "EventRef::remove");
            a.item("SelectRef", "EventRef::select");
        }
        static d(a) {
            WebChipDescriptionMetadata.b(a);
            a.ad("WebChip", () => new WebChipDescription());
            a.ac("WebChip", WebChipDescriptionMetadata.a);
        }
    }
    WebChipDescriptionMetadata.$t = /*@__PURE__*/ markType(WebChipDescriptionMetadata, 'WebChipDescriptionMetadata');
    WebChipDescriptionMetadata.a = null;
    return WebChipDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebChipDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescriptionMetadata } from "./WebComponentBoolValueChangedEventArgsDescriptionMetadata";
import { WebChipDescription } from "./WebChipDescription";
/**
 * @hidden
 */
export let WebChipDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebChipDescriptionMetadata extends Base {
        static b(a) {
            if (WebChipDescriptionMetadata.a == null) {
                WebChipDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebChipDescriptionMetadata.c(WebChipDescriptionMetadata.a);
            }
            if (a.k(WebChipDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebChipDescriptionMetadata.a);
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Chip");
            a.item("__tagNameWC", "String:igc-chip");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Disabled", "Boolean");
            a.item("Removable", "Boolean");
            a.item("Selectable", "Boolean");
            a.item("Selected", "Boolean");
            a.item("Variant", "ExportedType:string:StyleVariant");
            a.item("Variant@stringUnion", "WebComponents;React");
            a.item("Variant@names", "Primary;Info;Success;Warning;Danger");
            a.item("RemoveRef", "EventRef::remove");
            a.item("SelectRef", "EventRef::select");
        }
        static d(a) {
            WebChipDescriptionMetadata.b(a);
            a.ae("WebChip", () => new WebChipDescription());
            a.ad("WebChip", WebChipDescriptionMetadata.a);
        }
    }
    WebChipDescriptionMetadata.$t = /*@__PURE__*/ markType(WebChipDescriptionMetadata, 'WebChipDescriptionMetadata');
    WebChipDescriptionMetadata.a = null;
    return WebChipDescriptionMetadata;
})();
